@@ -17,6 +17,7 @@ import httplib
 import urllib 
 import urllib2
 import time
+import datetime
 import ConfigParser
 import optparse
 import zc.lockfile
@@ -391,7 +392,7 @@ class Mirror(object):
 
     def _index_html(self):
         header = "<html><body><h1>PyPI Mirror</h1><h2>Last update: " + \
-                 time.strftime("%c %Z")+"</h2>\n"
+                 datetime.datetime.utcnow().strftime("%c UTC")+"</h2>\n"
         _ls = self.ls()
         links = "<br />\n".join([self._html_link(link) for link in _ls])
         generator = "<p class='footer'>Generated by %s; %d packages mirrored. For details see the <a href='http://www.openplans.org/projects/pypi-mirroring'>pypi mirroring z3c.pypimirror project page.</a></p>" % (pypimirror_version(), len(_ls))
